summaryrefslogtreecommitdiff
path: root/usr/src/uts/common/sys
diff options
context:
space:
mode:
Diffstat (limited to 'usr/src/uts/common/sys')
-rw-r--r--usr/src/uts/common/sys/mdi_impldefs.h7
-rw-r--r--usr/src/uts/common/sys/scsi/adapters/scsi_vhci.h2
2 files changed, 8 insertions, 1 deletions
diff --git a/usr/src/uts/common/sys/scsi/adapters/scsi_vhci.h b/usr/src/uts/common/sys/scsi/adapters/scsi_vhci.h
index ed45f2f421..5be9bc402b 100644
--- a/usr/src/uts/common/sys/scsi/adapters/scsi_vhci.h
+++ b/usr/src/uts/common/sys/scsi/adapters/scsi_vhci.h
@@ -742,6 +742,8 @@ typedef struct sv_switch_to_cntlr_iocdata {
#define SCSI_VHCI_PATH_ENABLE (SCSI_VHCI_CTL_SUB_CMD + 0x0D)
#define SCSI_VHCI_MPAPI (SCSI_VHCI_CTL_SUB_CMD + 0x0E)
+#define SCSI_VHCI_GET_TARGET_LONGNAME (SCSI_VHCI_CTL_SUB_CMD + 0x0F)
+
#ifdef __cplusplus
}
#endif
diff --git a/usr/src/uts/common/sys/mdi_impldefs.h b/usr/src/uts/common/sys/mdi_impldefs.h
index 0c3a035339..4838c1ca7b 100644
--- a/usr/src/uts/common/sys/mdi_impldefs.h
+++ b/usr/src/uts/common/sys/mdi_impldefs.h
@@ -238,6 +238,9 @@ typedef struct mdi_vhci_ops {
/* Client path failover callback */
int (*vo_failover)(dev_info_t *vdip, dev_info_t *cdip, int flags);
+
+ /* Client attached callback */
+ void (*vo_client_attached)(dev_info_t *cdip);
} mdi_vhci_ops_t;
/*
@@ -1178,8 +1181,10 @@ int mdi_failover(dev_info_t *, dev_info_t *, int);
#define MDI_FAILOVER_ASYNC 2 /* Asyncronous Failover */
/*
* mdi_pathinfo node state change functions.
*/
+int mdi_pi_kstat_exists(mdi_pathinfo_t *);
+int mdi_pi_kstat_create(mdi_pathinfo_t *pip, char *ks_name);
void mdi_pi_kstat_iosupdate(mdi_pathinfo_t *, struct buf *);
/*
@@ -1178,8 +1181,10 @@ int mdi_failover(dev_info_t *, dev_info_t *, int);
#define MDI_FAILOVER_ASYNC 2 /* Asyncronous Failover */
/*
- * mdi_pathinfo node state change functions.
+ * mdi_pathinfo node kstat functions.
*/